@@ -1,7 +1,7 @@
 from .__about__ import __version__
 from .benchmark import show_kovesi_test_image, show_test_function
 from .create import create_colormap, find_max_srgb_radius, show_circular, show_linear
-from .main import get_srgb1, save_fig, save_img, tripcolor
+from .main import get_srgb1, imsave, plot, savefig, show, tripcolor
 
 __all__ = [
     "__version__",
@@ -14,8 +14,8 @@ __all__ = [
     "create_colormap",
     "show",
     "plot",
-    "save_fig",
-    "save_img",
+    "savefig",
+    "imsave",
     "get_srgb1",
     #
     "tripcolor",
